==> tuia-ecb-center-api-1.1.0.5-20200218.103339-3-sources.jar: cn/com/duiba/tuia/ecb/center/mix/req/MixPlayMyReq.java <==
package cn.com.duiba.tuia.ecb.center.mix.req;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * MixPlayMyReq
 *
 * @author jiangshikui
 * @date 2020/2/4
 **/
public class MixPlayMyReq implements Serializable {
    private static final long serialVersionUID = 4673406847109531219L;

    /**
     * 订单id
     */
    private Integer orderid;

    /**
     * 渠道编号 由我玩平台提供
     */
    private Integer cid;

    /**
     * 用户id
     */
    private String cuid;

    /**
     * 设备码
     */
    private String devid;

    /**
     * 任务名称
     */
    private String adname;

    /**
     * 时间
     */
    private String time;

    /**
     * 积分收益
     */
    private BigDecimal points;

    /**
     * 积分收益
     */
    private BigDecimal plat_points;

    /**
     * 渠道id
     */
    private String appid;

    /**
     * 用户领取的奖励类型
     */
    private Integer atype;

    /**
     * 签名
     */
    private String sign;

    public Integer getOrderid() {
        return orderid;
    }

    public void setOrderid(Integer orderid) {
        this.orderid = orderid;
    }

    public Integer getCid() {
        return cid;
    }

    public void setCid(Integer cid) {
        this.cid = cid;
    }

    public String getCuid() {
        return cuid;
    }

    public void setCuid(String cuid) {
        this.cuid = cuid;
    }

    public String getDevid() {
        return devid;
    }

    public void setDevid(String devid) {
        this.devid = devid;
    }

    public String getAdname() {
        return adname;
    }

    public void setAdname(String adname) {
        this.adname = adname;
    }

    public String getTime() {
        return time;
    }

    public void setTime(String time) {
        this.time = time;
    }

    public BigDecimal getPoints() {
        return points;
    }

    public void setPoints(BigDecimal points) {
        this.points = points;
    }

    public Integer getAtype() {
        return atype;
    }

    public void setAtype(Integer atype) {
        this.atype = atype;
    }

    public String getSign() {
        return sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }

    public BigDecimal getPlat_points() {
        return plat_points;
    }

    public void setPlat_points(BigDecimal plat_points) {
        this.plat_points = plat_points;
    }

    public String getAppid() {
        return appid;
    }

    public void setAppid(String appid) {
        this.appid = appid;
    }
}

==> tuia-ecb-center-api-1.1.1.26-sources.jar: cn/com/duiba/tuia/ecb/center/mix/req/MixPlayMyReq.java <==
package cn.com.duiba.tuia.ecb.center.mix.req;

import java.io.Serializable;

/**
 * MixPlayMyReq
 *
 * @author jiangshikui
 * @date 2020/2/4
 **/
public class MixPlayMyReq implements Serializable {
    private static final long serialVersionUID = 4673406847109531219L;

    /**
     * 订单id
     */
    private Integer orderid;

    /**
     * 渠道编号 由我玩平台提供
     */
    private Integer cid;

    /**
     * 用户id
     */
    private String cuid;

    /**
     * 设备码
     */
    private String devid;

    /**
     * 任务名称
     */
    private String adname;

    /**
     * 时间
     */
    private String time;

    /**
     * 积分收益
     */
    private String points;

    /**
     * 积分收益
     */
    private String plat_points;

    /**
     * 渠道id
     */
    private String appid;

    /**
     * 用户领取的奖励类型
     */
    private Integer atype;

    /**
     * 签名
     */
    private String sign;

    public Integer getOrderid() {
        return orderid;
    }

    public void setOrderid(Integer orderid) {
        this.orderid = orderid;
    }

    public Integer getCid() {
        return cid;
    }

    public void setCid(Integer cid) {
        this.cid = cid;
    }

    public String getCuid() {
        return cuid;
    }

    public void setCuid(String cuid) {
        this.cuid = cuid;
    }

    public String getDevid() {
        return devid;
    }

    public void setDevid(String devid) {
        this.devid = devid;
    }

    public String getAdname() {
        return adname;
    }

    public void setAdname(String adname) {
        this.adname = adname;
    }

    public String getTime() {
        return time;
    }

    public void setTime(String time) {
        this.time = time;
    }

    public String getPoints() {
        return points;
    }

    public void setPoints(String points) {
        this.points = points;
    }

    public Integer getAtype() {
        return atype;
    }

    public void setAtype(Integer atype) {
        this.atype = atype;
    }

    public String getSign() {
        return sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }

    public String getPlat_points() {
        return plat_points;
    }

    public void setPlat_points(String plat_points) {
        this.plat_points = plat_points;
    }

    public String getAppid() {
        return appid;
    }

    public void setAppid(String appid) {
        this.appid = appid;
    }
}
